/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediarecorder.sip"
#include <qmediarecorder.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaobject.sip"
#include <qmediaobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmultimedia.sip"
#include <qmultimedia.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaencodersettings.sip"
#include <qmediaencodersettings.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaencodersettings.sip"
#include <qmediaencodersettings.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 751 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 646 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"


class sipQMediaRecorder : public ::QMediaRecorder
{
public:
    sipQMediaRecorder(::QMediaObject*, ::QObject*);
    virtual ~sipQMediaRecorder();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QMediaObject* mediaObject() const SIP_OVERRIDE;
    bool setMediaObject(::QMediaObject*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQMediaRecorder(const sipQMediaRecorder &);
    sipQMediaRecorder &operator = (const sipQMediaRecorder &);

    char sipPyMethods[9];
};

sipQMediaRecorder::sipQMediaRecorder(::QMediaObject*a0, ::QObject*a1): ::QMediaRecorder(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQMediaRecorder::~sipQMediaRecorder()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQMediaRecorder::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QMediaRecorder);

    return ::QMediaRecorder::metaObject();
}

int sipQMediaRecorder::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QMediaRecorder::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QMediaRecorder, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQMediaRecorder::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QMediaRecorder, _clname, &sipCpp) ? sipCpp : ::QMediaRecorder::qt_metacast(_clname));
}

::QMediaObject* sipQMediaRecorder::mediaObject() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mediaObject);

    if (!sipMeth)
        return ::QMediaRecorder::mediaObject();

    extern ::QMediaObject* sipVH_QtMultimedia_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_36(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQMediaRecorder::setMediaObject(::QMediaObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_setMediaObject);

    if (!sipMeth)
        return ::QMediaRecorder::setMediaObject(a0);

    extern bool sipVH_QtMultimedia_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMediaObject*);

    return sipVH_QtMultimedia_37(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQMediaRecorder::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QMediaRecorder::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQMediaRecorder::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QMediaRecorder::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQMediaRecorder::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QMediaRecorder::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorder::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QMediaRecorder::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorder::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QMediaRecorder::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorder::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QMediaRecorder::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorder::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QMediaRecorder::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QMediaRecorder_mediaObject, "mediaObject(self) -> Optional[QMediaObject]");

extern "C" {static PyObject *meth_QMediaRecorder_mediaObject(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_mediaObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QMediaObject*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QMediaRecorder::mediaObject() : sipCpp->mediaObject());

            return sipConvertFromType(sipRes, sipType_QMediaObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_mediaObject, doc_QMediaRecorder_mediaObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_isAvailable, "isAvailable(self) -> bool");

extern "C" {static PyObject *meth_QMediaRecorder_isAvailable(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_isAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_isAvailable, doc_QMediaRecorder_isAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_availability, "availability(self) -> QMultimedia.AvailabilityStatus");

extern "C" {static PyObject *meth_QMediaRecorder_availability(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_availability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QMultimedia::AvailabilityStatus sipRes;

            sipRes = sipCpp->availability();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMultimedia_AvailabilityStatus);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_availability, doc_QMediaRecorder_availability);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_outputLocation, "outputLocation(self) -> QUrl");

extern "C" {static PyObject *meth_QMediaRecorder_outputLocation(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_outputLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->outputLocation());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_outputLocation, doc_QMediaRecorder_outputLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setOutputLocation, "setOutputLocation(self, location: QUrl) -> bool");

extern "C" {static PyObject *meth_QMediaRecorder_setOutputLocation(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setOutputLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QUrl, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->setOutputLocation(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setOutputLocation, doc_QMediaRecorder_setOutputLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_actualLocation, "actualLocation(self) -> QUrl");

extern "C" {static PyObject *meth_QMediaRecorder_actualLocation(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_actualLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->actualLocation());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_actualLocation, doc_QMediaRecorder_actualLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_state, "state(self) -> QMediaRecorder.State");

extern "C" {static PyObject *meth_QMediaRecorder_state(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QMediaRecorder::State sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaRecorder_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_state, doc_QMediaRecorder_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_status, "status(self) -> QMediaRecorder.Status");

extern "C" {static PyObject *meth_QMediaRecorder_status(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_status(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QMediaRecorder::Status sipRes;

            sipRes = sipCpp->status();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaRecorder_Status);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_status, doc_QMediaRecorder_status);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_error, "error(self) -> QMediaRecorder.Error");

extern "C" {static PyObject *meth_QMediaRecorder_error(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QMediaRecorder::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaRecorder_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_error, doc_QMediaRecorder_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QMediaRecorder_errorString(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_errorString, doc_QMediaRecorder_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_duration, "duration(self) -> int");

extern "C" {static PyObject *meth_QMediaRecorder_duration(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_duration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->duration();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_duration, doc_QMediaRecorder_duration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_isMuted, "isMuted(self) -> bool");

extern "C" {static PyObject *meth_QMediaRecorder_isMuted(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_isMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMuted();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_isMuted, doc_QMediaRecorder_isMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_volume, "volume(self) -> float");

extern "C" {static PyObject *meth_QMediaRecorder_volume(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_volume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->volume();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_volume, doc_QMediaRecorder_volume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_supportedContainers, "supportedContainers(self) -> list[str]");

extern "C" {static PyObject *meth_QMediaRecorder_supportedContainers(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_supportedContainers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->supportedContainers());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_supportedContainers, doc_QMediaRecorder_supportedContainers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_containerDescription, "containerDescription(self, format: Optional[str]) -> str");

extern "C" {static PyObject *meth_QMediaRecorder_containerDescription(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_containerDescription(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->containerDescription(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_containerDescription, doc_QMediaRecorder_containerDescription);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_supportedAudioCodecs, "supportedAudioCodecs(self) -> list[str]");

extern "C" {static PyObject *meth_QMediaRecorder_supportedAudioCodecs(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_supportedAudioCodecs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->supportedAudioCodecs());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_supportedAudioCodecs, doc_QMediaRecorder_supportedAudioCodecs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_audioCodecDescription, "audioCodecDescription(self, codecName: Optional[str]) -> str");

extern "C" {static PyObject *meth_QMediaRecorder_audioCodecDescription(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_audioCodecDescription(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->audioCodecDescription(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_audioCodecDescription, doc_QMediaRecorder_audioCodecDescription);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_supportedAudioSampleRates, "supportedAudioSampleRates(self, settings: QAudioEncoderSettings = QAudioEncoderSettings()) -> (list[int], Optional[bool])");

extern "C" {static PyObject *meth_QMediaRecorder_supportedAudioSampleRates(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_supportedAudioSampleRates(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEncoderSettings& a0def = QAudioEncoderSettings();
        const ::QAudioEncoderSettings* a0 = &a0def;
        bool a1;
        const ::QMediaRecorder *sipCpp;

        static const char *sipKwdList[] = {
            sipName_settings,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QAudioEncoderSettings, &a0))
        {
            ::QList<int>*sipRes;

            sipRes = new ::QList<int>(sipCpp->supportedAudioSampleRates(*a0, &a1));

            PyObject *sipResObj = sipConvertFromNewType(sipRes, sipType_QList_1800, SIP_NULLPTR);
            return sipBuildResult(0, "(Rb)", sipResObj, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_supportedAudioSampleRates, doc_QMediaRecorder_supportedAudioSampleRates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_supportedVideoCodecs, "supportedVideoCodecs(self) -> list[str]");

extern "C" {static PyObject *meth_QMediaRecorder_supportedVideoCodecs(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_supportedVideoCodecs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->supportedVideoCodecs());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_supportedVideoCodecs, doc_QMediaRecorder_supportedVideoCodecs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_videoCodecDescription, "videoCodecDescription(self, codecName: Optional[str]) -> str");

extern "C" {static PyObject *meth_QMediaRecorder_videoCodecDescription(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_videoCodecDescription(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->videoCodecDescription(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_videoCodecDescription, doc_QMediaRecorder_videoCodecDescription);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_supportedResolutions, "supportedResolutions(self, settings: QVideoEncoderSettings = QVideoEncoderSettings()) -> (list[QSize], Optional[bool])");

extern "C" {static PyObject *meth_QMediaRecorder_supportedResolutions(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_supportedResolutions(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVideoEncoderSettings& a0def = QVideoEncoderSettings();
        const ::QVideoEncoderSettings* a0 = &a0def;
        bool a1;
        const ::QMediaRecorder *sipCpp;

        static const char *sipKwdList[] = {
            sipName_settings,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QVideoEncoderSettings, &a0))
        {
            QList< ::QSize>*sipRes;

            sipRes = new QList< ::QSize>(sipCpp->supportedResolutions(*a0, &a1));

            PyObject *sipResObj = sipConvertFromNewType(sipRes, sipType_QList_0100QSize, SIP_NULLPTR);
            return sipBuildResult(0, "(Rb)", sipResObj, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_supportedResolutions, doc_QMediaRecorder_supportedResolutions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_supportedFrameRates, "supportedFrameRates(self, settings: QVideoEncoderSettings = QVideoEncoderSettings()) -> (list[float], Optional[bool])");

extern "C" {static PyObject *meth_QMediaRecorder_supportedFrameRates(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_supportedFrameRates(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVideoEncoderSettings& a0def = QVideoEncoderSettings();
        const ::QVideoEncoderSettings* a0 = &a0def;
        bool a1;
        const ::QMediaRecorder *sipCpp;

        static const char *sipKwdList[] = {
            sipName_settings,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QVideoEncoderSettings, &a0))
        {
            ::QList< ::qreal>*sipRes;

            sipRes = new ::QList< ::qreal>(sipCpp->supportedFrameRates(*a0, &a1));

            PyObject *sipResObj = sipConvertFromNewType(sipRes, sipType_QList_2400, SIP_NULLPTR);
            return sipBuildResult(0, "(Rb)", sipResObj, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_supportedFrameRates, doc_QMediaRecorder_supportedFrameRates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_audioSettings, "audioSettings(self) -> QAudioEncoderSettings");

extern "C" {static PyObject *meth_QMediaRecorder_audioSettings(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_audioSettings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QAudioEncoderSettings*sipRes;

            sipRes = new ::QAudioEncoderSettings(sipCpp->audioSettings());

            return sipConvertFromNewType(sipRes, sipType_QAudioEncoderSettings, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_audioSettings, doc_QMediaRecorder_audioSettings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_videoSettings, "videoSettings(self) -> QVideoEncoderSettings");

extern "C" {static PyObject *meth_QMediaRecorder_videoSettings(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_videoSettings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QVideoEncoderSettings*sipRes;

            sipRes = new ::QVideoEncoderSettings(sipCpp->videoSettings());

            return sipConvertFromNewType(sipRes, sipType_QVideoEncoderSettings, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_videoSettings, doc_QMediaRecorder_videoSettings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_containerFormat, "containerFormat(self) -> str");

extern "C" {static PyObject *meth_QMediaRecorder_containerFormat(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_containerFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->containerFormat());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_containerFormat, doc_QMediaRecorder_containerFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setAudioSettings, "setAudioSettings(self, audioSettings: QAudioEncoderSettings)");

extern "C" {static PyObject *meth_QMediaRecorder_setAudioSettings(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setAudioSettings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEncoderSettings* a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QAudioEncoderSettings, &a0))
        {
            sipCpp->setAudioSettings(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setAudioSettings, doc_QMediaRecorder_setAudioSettings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setVideoSettings, "setVideoSettings(self, videoSettings: QVideoEncoderSettings)");

extern "C" {static PyObject *meth_QMediaRecorder_setVideoSettings(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setVideoSettings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVideoEncoderSettings* a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QVideoEncoderSettings, &a0))
        {
            sipCpp->setVideoSettings(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setVideoSettings, doc_QMediaRecorder_setVideoSettings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setContainerFormat, "setContainerFormat(self, container: Optional[str])");

extern "C" {static PyObject *meth_QMediaRecorder_setContainerFormat(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setContainerFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setContainerFormat(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setContainerFormat, doc_QMediaRecorder_setContainerFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setEncodingSettings, "setEncodingSettings(self, audio: QAudioEncoderSettings, video: QVideoEncoderSettings = QVideoEncoderSettings(), container: Optional[str] = '')");

extern "C" {static PyObject *meth_QMediaRecorder_setEncodingSettings(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setEncodingSettings(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEncoderSettings* a0;
        const ::QVideoEncoderSettings& a1def = QVideoEncoderSettings();
        const ::QVideoEncoderSettings* a1 = &a1def;
        const ::QString& a2def = QString();
        const ::QString* a2 = &a2def;
        int a2State = 0;
        ::QMediaRecorder *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_video,
            sipName_container,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|J9J1", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QAudioEncoderSettings, &a0, sipType_QVideoEncoderSettings, &a1, sipType_QString, &a2, &a2State))
        {
            sipCpp->setEncodingSettings(*a0, *a1, *a2);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setEncodingSettings, doc_QMediaRecorder_setEncodingSettings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_isMetaDataAvailable, "isMetaDataAvailable(self) -> bool");

extern "C" {static PyObject *meth_QMediaRecorder_isMetaDataAvailable(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_isMetaDataAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMetaDataAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_isMetaDataAvailable, doc_QMediaRecorder_isMetaDataAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_isMetaDataWritable, "isMetaDataWritable(self) -> bool");

extern "C" {static PyObject *meth_QMediaRecorder_isMetaDataWritable(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_isMetaDataWritable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMetaDataWritable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_isMetaDataWritable, doc_QMediaRecorder_isMetaDataWritable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_metaData, "metaData(self, key: Optional[str]) -> Any");

extern "C" {static PyObject *meth_QMediaRecorder_metaData(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_metaData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->metaData(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_metaData, doc_QMediaRecorder_metaData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setMetaData, "setMetaData(self, key: Optional[str], value: Any)");

extern "C" {static PyObject *meth_QMediaRecorder_setMetaData(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setMetaData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            sipCpp->setMetaData(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setMetaData, doc_QMediaRecorder_setMetaData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_availableMetaData, "availableMetaData(self) -> list[str]");

extern "C" {static PyObject *meth_QMediaRecorder_availableMetaData(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_availableMetaData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->availableMetaData());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_availableMetaData, doc_QMediaRecorder_availableMetaData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_record, "record(self)");

extern "C" {static PyObject *meth_QMediaRecorder_record(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_record(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            sipCpp->record();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_record, doc_QMediaRecorder_record);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_pause, "pause(self)");

extern "C" {static PyObject *meth_QMediaRecorder_pause(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_pause(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            sipCpp->pause();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_pause, doc_QMediaRecorder_pause);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_stop, "stop(self)");

extern "C" {static PyObject *meth_QMediaRecorder_stop(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_stop, doc_QMediaRecorder_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setMuted, "setMuted(self, muted: bool)");

extern "C" {static PyObject *meth_QMediaRecorder_setMuted(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QMediaRecorder, &sipCpp, &a0))
        {
            sipCpp->setMuted(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setMuted, doc_QMediaRecorder_setMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setVolume, "setVolume(self, volume: float)");

extern "C" {static PyObject *meth_QMediaRecorder_setVolume(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setVolume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QMediaRecorder, &sipCpp, &a0))
        {
            sipCpp->setVolume(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setVolume, doc_QMediaRecorder_setVolume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setMediaObject, "setMediaObject(self, object: Optional[QMediaObject]) -> bool");

extern "C" {static PyObject *meth_QMediaRecorder_setMediaObject(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setMediaObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMediaObject* a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QMediaObject, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QMediaRecorder::setMediaObject(a0) : sipCpp->setMediaObject(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setMediaObject, doc_QMediaRecorder_setMediaObject);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QMediaRecorder(void *, const sipTypeDef *);}
static void *cast_QMediaRecorder(void *sipCppV, const sipTypeDef *targetType)
{
    ::QMediaRecorder *sipCpp = reinterpret_cast< ::QMediaRecorder *>(sipCppV);

    if (targetType == sipType_QMediaRecorder)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    if (targetType == sipType_QMediaBindableInterface)
        return static_cast< ::QMediaBindableInterface *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QMediaRecorder(void *, int);}
static void release_QMediaRecorder(void *sipCppV, int)
{
    ::QMediaRecorder *sipCpp = reinterpret_cast< ::QMediaRecorder *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QMediaRecorder(sipSimpleWrapper *);}
static void dealloc_QMediaRecorder(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQMediaRecorder *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMediaRecorder(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QMediaRecorder(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMediaRecorder(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQMediaRecorder *sipCpp = SIP_NULLPTR;

    {
        ::QMediaObject* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JH", sipType_QMediaObject, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQMediaRecorder(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QMediaRecorder[] = {{9, 0, 0}, {101, 255, 1}};


static PyMethodDef methods_QMediaRecorder[] = {
    {sipName_actualLocation, meth_QMediaRecorder_actualLocation, METH_VARARGS, doc_QMediaRecorder_actualLocation},
    {sipName_audioCodecDescription, meth_QMediaRecorder_audioCodecDescription, METH_VARARGS, doc_QMediaRecorder_audioCodecDescription},
    {sipName_audioSettings, meth_QMediaRecorder_audioSettings, METH_VARARGS, doc_QMediaRecorder_audioSettings},
    {sipName_availability, meth_QMediaRecorder_availability, METH_VARARGS, doc_QMediaRecorder_availability},
    {sipName_availableMetaData, meth_QMediaRecorder_availableMetaData, METH_VARARGS, doc_QMediaRecorder_availableMetaData},
    {sipName_containerDescription, meth_QMediaRecorder_containerDescription, METH_VARARGS, doc_QMediaRecorder_containerDescription},
    {sipName_containerFormat, meth_QMediaRecorder_containerFormat, METH_VARARGS, doc_QMediaRecorder_containerFormat},
    {sipName_duration, meth_QMediaRecorder_duration, METH_VARARGS, doc_QMediaRecorder_duration},
    {sipName_error, meth_QMediaRecorder_error, METH_VARARGS, doc_QMediaRecorder_error},
    {sipName_errorString, meth_QMediaRecorder_errorString, METH_VARARGS, doc_QMediaRecorder_errorString},
    {sipName_isAvailable, meth_QMediaRecorder_isAvailable, METH_VARARGS, doc_QMediaRecorder_isAvailable},
    {sipName_isMetaDataAvailable, meth_QMediaRecorder_isMetaDataAvailable, METH_VARARGS, doc_QMediaRecorder_isMetaDataAvailable},
    {sipName_isMetaDataWritable, meth_QMediaRecorder_isMetaDataWritable, METH_VARARGS, doc_QMediaRecorder_isMetaDataWritable},
    {sipName_isMuted, meth_QMediaRecorder_isMuted, METH_VARARGS, doc_QMediaRecorder_isMuted},
    {sipName_mediaObject, meth_QMediaRecorder_mediaObject, METH_VARARGS, doc_QMediaRecorder_mediaObject},
    {sipName_metaData, meth_QMediaRecorder_metaData, METH_VARARGS, doc_QMediaRecorder_metaData},
    {sipName_outputLocation, meth_QMediaRecorder_outputLocation, METH_VARARGS, doc_QMediaRecorder_outputLocation},
    {sipName_pause, meth_QMediaRecorder_pause, METH_VARARGS, doc_QMediaRecorder_pause},
    {sipName_record, meth_QMediaRecorder_record, METH_VARARGS, doc_QMediaRecorder_record},
    {sipName_setAudioSettings, meth_QMediaRecorder_setAudioSettings, METH_VARARGS, doc_QMediaRecorder_setAudioSettings},
    {sipName_setContainerFormat, meth_QMediaRecorder_setContainerFormat, METH_VARARGS, doc_QMediaRecorder_setContainerFormat},
    {sipName_setEncodingSettings, SIP_MLMETH_CAST(meth_QMediaRecorder_setEncodingSettings), METH_VARARGS|METH_KEYWORDS, doc_QMediaRecorder_setEncodingSettings},
    {sipName_setMediaObject, meth_QMediaRecorder_setMediaObject, METH_VARARGS, doc_QMediaRecorder_setMediaObject},
    {sipName_setMetaData, meth_QMediaRecorder_setMetaData, METH_VARARGS, doc_QMediaRecorder_setMetaData},
    {sipName_setMuted, meth_QMediaRecorder_setMuted, METH_VARARGS, doc_QMediaRecorder_setMuted},
    {sipName_setOutputLocation, meth_QMediaRecorder_setOutputLocation, METH_VARARGS, doc_QMediaRecorder_setOutputLocation},
    {sipName_setVideoSettings, meth_QMediaRecorder_setVideoSettings, METH_VARARGS, doc_QMediaRecorder_setVideoSettings},
    {sipName_setVolume, meth_QMediaRecorder_setVolume, METH_VARARGS, doc_QMediaRecorder_setVolume},
    {sipName_state, meth_QMediaRecorder_state, METH_VARARGS, doc_QMediaRecorder_state},
    {sipName_status, meth_QMediaRecorder_status, METH_VARARGS, doc_QMediaRecorder_status},
    {sipName_stop, meth_QMediaRecorder_stop, METH_VARARGS, doc_QMediaRecorder_stop},
    {sipName_supportedAudioCodecs, meth_QMediaRecorder_supportedAudioCodecs, METH_VARARGS, doc_QMediaRecorder_supportedAudioCodecs},
    {sipName_supportedAudioSampleRates, SIP_MLMETH_CAST(meth_QMediaRecorder_supportedAudioSampleRates), METH_VARARGS|METH_KEYWORDS, doc_QMediaRecorder_supportedAudioSampleRates},
    {sipName_supportedContainers, meth_QMediaRecorder_supportedContainers, METH_VARARGS, doc_QMediaRecorder_supportedContainers},
    {sipName_supportedFrameRates, SIP_MLMETH_CAST(meth_QMediaRecorder_supportedFrameRates), METH_VARARGS|METH_KEYWORDS, doc_QMediaRecorder_supportedFrameRates},
    {sipName_supportedResolutions, SIP_MLMETH_CAST(meth_QMediaRecorder_supportedResolutions), METH_VARARGS|METH_KEYWORDS, doc_QMediaRecorder_supportedResolutions},
    {sipName_supportedVideoCodecs, meth_QMediaRecorder_supportedVideoCodecs, METH_VARARGS, doc_QMediaRecorder_supportedVideoCodecs},
    {sipName_videoCodecDescription, meth_QMediaRecorder_videoCodecDescription, METH_VARARGS, doc_QMediaRecorder_videoCodecDescription},
    {sipName_videoSettings, meth_QMediaRecorder_videoSettings, METH_VARARGS, doc_QMediaRecorder_videoSettings},
    {sipName_volume, meth_QMediaRecorder_volume, METH_VARARGS, doc_QMediaRecorder_volume}
};

static sipEnumMemberDef enummembers_QMediaRecorder[] = {
    {sipName_FinalizingStatus, static_cast<int>(::QMediaRecorder::FinalizingStatus), 122},
    {sipName_FormatError, static_cast<int>(::QMediaRecorder::FormatError), 120},
    {sipName_LoadedStatus, static_cast<int>(::QMediaRecorder::LoadedStatus), 122},
    {sipName_LoadingStatus, static_cast<int>(::QMediaRecorder::LoadingStatus), 122},
    {sipName_NoError, static_cast<int>(::QMediaRecorder::NoError), 120},
    {sipName_OutOfSpaceError, static_cast<int>(::QMediaRecorder::OutOfSpaceError), 120},
    {sipName_PausedState, static_cast<int>(::QMediaRecorder::PausedState), 121},
    {sipName_PausedStatus, static_cast<int>(::QMediaRecorder::PausedStatus), 122},
    {sipName_RecordingState, static_cast<int>(::QMediaRecorder::RecordingState), 121},
    {sipName_RecordingStatus, static_cast<int>(::QMediaRecorder::RecordingStatus), 122},
    {sipName_ResourceError, static_cast<int>(::QMediaRecorder::ResourceError), 120},
    {sipName_StartingStatus, static_cast<int>(::QMediaRecorder::StartingStatus), 122},
    {sipName_StoppedState, static_cast<int>(::QMediaRecorder::StoppedState), 121},
    {sipName_UnavailableStatus, static_cast<int>(::QMediaRecorder::UnavailableStatus), 122},
    {sipName_UnloadedStatus, static_cast<int>(::QMediaRecorder::UnloadedStatus), 122},
};

PyDoc_STRVAR(doc_QMediaRecorder, "\1QMediaRecorder(mediaObject: Optional[QMediaObject], parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QMediaRecorder[] = {
    {"availabilityChanged(QMultimedia::AvailabilityStatus)", "\1availabilityChanged(self, availability: QMultimedia.AvailabilityStatus)", SIP_NULLPTR, SIP_NULLPTR},
    {"availabilityChanged(bool)", "\1availabilityChanged(self, available: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"metaDataChanged(QString,QVariant)", "\1metaDataChanged(self, key: Optional[str], value: Any)", SIP_NULLPTR, SIP_NULLPTR},
    {"metaDataChanged()", "\1metaDataChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"metaDataWritableChanged(bool)", "\1metaDataWritableChanged(self, writable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"metaDataAvailableChanged(bool)", "\1metaDataAvailableChanged(self, available: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"actualLocationChanged(QUrl)", "\1actualLocationChanged(self, location: QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {"volumeChanged(qreal)", "\1volumeChanged(self, volume: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"mutedChanged(bool)", "\1mutedChanged(self, muted: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"durationChanged(qint64)", "\1durationChanged(self, duration: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"statusChanged(QMediaRecorder::Status)", "\1statusChanged(self, status: QMediaRecorder.Status)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QMediaRecorder::State)", "\1stateChanged(self, state: QMediaRecorder.State)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QMediaRecorder::Error)", "\1error(self, error: QMediaRecorder.Error)", &methods_QMediaRecorder[8], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QMediaRecorder = {
    &::QMediaRecorder::staticMetaObject,
    0,
    signals_QMediaRecorder,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QMediaRecorder = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMediaRecorder,
        SIP_NULLPTR,
        &plugin_QMediaRecorder,
    },
    {
        sipNameNr_QMediaRecorder,
        {0, 0, 1},
        40, methods_QMediaRecorder,
        15, enummembers_QMediaRecorder,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMediaRecorder,
    -1,
    -1,
    supers_QMediaRecorder,
    SIP_NULLPTR,
    init_type_QMediaRecorder,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMediaRecorder,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QMediaRecorder,
    cast_QMediaRecorder,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QMediaRecorder),
};
